//
// anyRemote
// a bluetooth remote for your PC.
//
// Copyright (C) 2011-2012 Mikhail Fedotov <anyremote@mail.ru>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef _PR_WEB_H
#define _PR_WEB_H

#include "dispatcher.h"
#include "peer.h"

enum arRequestType {
    RQ_UNKNOWN=0,
    RQ_GET,
    RQ_POST
};

typedef struct {
    int        button;
    string_t*  string;
} wMessage;

int  openWeb     (ConnectInfo* connInfo);
void closeWebPort(ConnectInfo* connInfo, int final);
int  checkWebPort();
int  writeWebConn(const dMessage* dm, int mode);
int  writeWeb    (ConnectInfo* peer, const dMessage* dm);

void freeWMessage(void *buf);

#endif
